@@ -40,9 +40,7 @@ from os.path import join
 scripts = [join('bin', 'logilab-pytest')]
 include_dirs = [join('test', 'data')]
 
-install_requires = [
-        'six >= 1.4.0',
-        ]
+install_requires = []
 tests_require = ['pytz']
 
 if sys.version_info < (2, 7):
