@@ -61,6 +61,17 @@ class RawInputTC(TestCase):
         self.assertEqual(self.messages,
                          ['[logilab.common] OldClass is deprecated, use AnyClass instead'])
 
+    def test_class_renamed_conflict_metaclass(self):
+        class SomeMetaClass(type):
+            pass
+
+        class AnyClass(metaclass=SomeMetaClass):
+            pass
+
+        # make sure the "metaclass conflict: the metaclass of a derived class # must be a
+        # (non-strict) subclass of the metaclasses of all its bases" exception won't be raised
+        deprecation.class_renamed("OldClass", AnyClass)
+
     def test_class_moved(self):
         class AnyClass(object):
             pass
